@@ -567,7 +567,12 @@ rstto_file_get_thumbnail (RsttoFile *r_file,
     const gchar *thumbnail_path;
     guint n_pixels;
 
+    /* get the flavor, trying to fall back on lower qualities if necessary */
     flavor = rstto_util_get_thumbnail_flavor (size);
+    while (r_file->priv->thumbnail_states[flavor] == RSTTO_THUMBNAIL_STATE_ERROR
+           && flavor > RSTTO_THUMBNAIL_FLAVOR_NORMAL)
+        flavor--;
+
     switch (r_file->priv->thumbnail_states[flavor])
     {
         case RSTTO_THUMBNAIL_STATE_PROCESSED:
@@ -616,6 +621,9 @@ rstto_file_get_thumbnail (RsttoFile *r_file,
         return NULL;
     }
 
+    if (r_file->priv->pixbufs[size] != NULL)
+        g_object_unref (r_file->priv->pixbufs[size]);
+
     n_pixels = rstto_util_get_thumbnail_n_pixels (size);
     r_file->priv->pixbufs[size] =
         gdk_pixbuf_new_from_file_at_scale (thumbnail_path, n_pixels, n_pixels, TRUE, &error);
