@@ -46,26 +46,35 @@ typedef enum
     RSTTO_SCALE_REAL_SIZE
 } RsttoScale;
 
-#define THUMBNAIL_SIZE_VERY_SMALL_SIZE   24
-#define THUMBNAIL_SIZE_SMALLER_SIZE      32
-#define THUMBNAIL_SIZE_SMALL_SIZE        48
-#define THUMBNAIL_SIZE_NORMAL_SIZE       64
-#define THUMBNAIL_SIZE_LARGE_SIZE        96
-#define THUMBNAIL_SIZE_LARGER_SIZE      128
-#define THUMBNAIL_SIZE_VERY_LARGE_SIZE  256
+typedef enum
+{
+    RSTTO_THUMBNAIL_FLAVOR_NORMAL,
+    RSTTO_THUMBNAIL_FLAVOR_LARGE,
+    RSTTO_THUMBNAIL_FLAVOR_X_LARGE,
+    RSTTO_THUMBNAIL_FLAVOR_XX_LARGE,
+    RSTTO_THUMBNAIL_FLAVOR_COUNT
+} RsttoThumbnailFlavor;
 
 typedef enum
 {
-    THUMBNAIL_SIZE_VERY_SMALL = 0,
-    THUMBNAIL_SIZE_SMALLER,
-    THUMBNAIL_SIZE_SMALL,
-    THUMBNAIL_SIZE_NORMAL,
-    THUMBNAIL_SIZE_LARGE,
-    THUMBNAIL_SIZE_LARGER,
-    THUMBNAIL_SIZE_VERY_LARGE,
-    THUMBNAIL_SIZE_COUNT,
+    RSTTO_THUMBNAIL_SIZE_VERY_SMALL,
+    RSTTO_THUMBNAIL_SIZE_SMALLER,
+    RSTTO_THUMBNAIL_SIZE_SMALL,
+    RSTTO_THUMBNAIL_SIZE_NORMAL,
+    RSTTO_THUMBNAIL_SIZE_LARGE,
+    RSTTO_THUMBNAIL_SIZE_LARGER,
+    RSTTO_THUMBNAIL_SIZE_VERY_LARGE,
+    RSTTO_THUMBNAIL_SIZE_COUNT,
 } RsttoThumbnailSize;
 
+typedef enum
+{
+    RSTTO_THUMBNAIL_STATE_UNPROCESSED,
+    RSTTO_THUMBNAIL_STATE_IN_PROCESS,
+    RSTTO_THUMBNAIL_STATE_PROCESSED,
+    RSTTO_THUMBNAIL_STATE_ERROR
+} RsttoThumbnailState;
+
 
 
 #define RSTTO_TYPE_FILE rstto_file_get_type ()
@@ -90,10 +99,6 @@ rstto_file_is_valid (RsttoFile *r_file);
 GFile *
 rstto_file_get_file (RsttoFile *r_file);
 
-gboolean
-rstto_file_equal (RsttoFile *r_file_a,
-                  RsttoFile *r_file_b);
-
 const gchar *
 rstto_file_get_display_name (RsttoFile *r_file);
 
@@ -113,8 +118,10 @@ void
 rstto_file_set_content_type (RsttoFile *r_file,
                              const gchar *type);
 
-const gchar *
-rstto_file_get_thumbnail_path (RsttoFile *r_file);
+void
+rstto_file_set_thumbnail_state (RsttoFile *r_file,
+                                RsttoThumbnailFlavor flavor,
+                                RsttoThumbnailState state);
 
 const GdkPixbuf *
 rstto_file_get_thumbnail (RsttoFile *r_file,
