@@ -60,6 +60,8 @@ cb_rstto_thumbnailer_request_finished (TumblerThumbnailer1 *proxy,
                                        gpointer data);
 static gboolean
 rstto_thumbnailer_queue_request_timer (gpointer user_data);
+static void
+rstto_thumbnailer_queue_request_timer_destroy (gpointer user_data);
 
 
 
@@ -69,7 +71,8 @@ struct _RsttoThumbnailerPrivate
     TumblerThumbnailer1 *proxy;
     RsttoSettings       *settings;
 
-    GSList              *queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
+    GSList              *remove_queue,
+                        *queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
                         *in_process_queues[RSTTO_THUMBNAIL_FLAVOR_COUNT],
                         *handles[RSTTO_THUMBNAIL_FLAVOR_COUNT];
     guint                request_timer_ids[RSTTO_THUMBNAIL_FLAVOR_COUNT];
@@ -86,9 +89,12 @@ G_DEFINE_TYPE_WITH_PRIVATE (RsttoThumbnailer, rstto_thumbnailer, G_TYPE_OBJECT)
 static void
 rstto_thumbnailer_init (RsttoThumbnailer *thumbnailer)
 {
+    GError *error = NULL;
+
     thumbnailer->priv = rstto_thumbnailer_get_instance_private (thumbnailer);
-    thumbnailer->priv->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+    thumbnailer->priv->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
     thumbnailer->priv->settings = rstto_settings_new ();
+    thumbnailer->priv->remove_queue = NULL;
     for (gint n = 0; n < RSTTO_THUMBNAIL_FLAVOR_COUNT; n++)
     {
         thumbnailer->priv->queues[n] = NULL;
@@ -110,14 +116,23 @@ rstto_thumbnailer_init (RsttoThumbnailer *thumbnailer)
                 TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1",
                 TUMBLER_SERVICE_PATH_PREFIX "/Thumbnailer1",
                 NULL,
-                NULL);
+                &error);
 
-        g_signal_connect (thumbnailer->priv->proxy, "ready",
-                          G_CALLBACK (cb_rstto_thumbnailer_thumbnail_ready), thumbnailer);
-        g_signal_connect (thumbnailer->priv->proxy, "error",
-                          G_CALLBACK (cb_rstto_thumbnailer_thumbnail_error), thumbnailer);
-        g_signal_connect (thumbnailer->priv->proxy, "finished",
-                          G_CALLBACK (cb_rstto_thumbnailer_request_finished), thumbnailer);
+        if (thumbnailer->priv->proxy != NULL)
+        {
+            g_signal_connect (thumbnailer->priv->proxy, "ready",
+                              G_CALLBACK (cb_rstto_thumbnailer_thumbnail_ready), thumbnailer);
+            g_signal_connect (thumbnailer->priv->proxy, "error",
+                              G_CALLBACK (cb_rstto_thumbnailer_thumbnail_error), thumbnailer);
+            g_signal_connect (thumbnailer->priv->proxy, "finished",
+                              G_CALLBACK (cb_rstto_thumbnailer_request_finished), thumbnailer);
+        }
+    }
+
+    if (error != NULL)
+    {
+        g_warning ("Unable to create a D-Bus proxy for the thumbnailing service: %s", error->message);
+        g_error_free (error);
     }
 }
 
@@ -163,11 +178,13 @@ rstto_thumbnailer_finalize (GObject *object)
 {
     RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (object);
 
+    g_slist_free_full (thumbnailer->priv->remove_queue, g_object_unref);
     for (gint n = 0; n < RSTTO_THUMBNAIL_FLAVOR_COUNT; n++)
     {
-        for (GSList *l = thumbnailer->priv->handles[n]; l != NULL; l = l->next)
-            tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
-                                                    GPOINTER_TO_UINT (l->data), NULL, NULL);
+        if (thumbnailer->priv->proxy != NULL)
+            for (GSList *l = thumbnailer->priv->handles[n]; l != NULL; l = l->next)
+                tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
+                                                        GPOINTER_TO_UINT (l->data), NULL, NULL);
 
         g_slist_free (thumbnailer->priv->handles[n]);
         g_slist_free_full (thumbnailer->priv->queues[n], g_object_unref);
@@ -235,7 +252,8 @@ rstto_thumbnailer_queue_file (RsttoThumbnailer *thumbnailer,
         g_slist_prepend (thumbnailer->priv->queues[flavor], g_object_ref (file));
     thumbnailer->priv->request_timer_ids[flavor] =
         g_timeout_add_full (G_PRIORITY_LOW, 300, rstto_thumbnailer_queue_request_timer,
-                            rstto_util_source_autoremove (thumbnailer), NULL);
+                            rstto_util_source_autoremove (thumbnailer),
+                            rstto_thumbnailer_queue_request_timer_destroy);
 }
 
 static RsttoThumbnailFlavor
@@ -256,7 +274,6 @@ static gboolean
 rstto_thumbnailer_queue_request_timer (gpointer user_data)
 {
     RsttoThumbnailer *thumbnailer = user_data;
-    RsttoImageList *image_list;
     RsttoThumbnailFlavor flavor;
     GtkWidget *error_dialog, *vbox, *do_not_show_checkbox;
     GSList *iter, *temp = NULL;
@@ -268,7 +285,6 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
     g_return_val_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer), FALSE);
 
     flavor = rstto_thumbnailer_get_timer_flavor (thumbnailer);
-    image_list = rstto_main_window_get_app_image_list ();
     n_items = rstto_icon_bar_get_n_visible_items (rstto_main_window_get_app_icon_bar ());
     uris = g_new0 (const gchar *, n_items + 1);
     mimetypes = g_new0 (const gchar *, n_items + 1);
@@ -276,7 +292,7 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
     /* dequeue files in process: they will eventually be re-queued after those
      * of the current request */
     iter = thumbnailer->priv->handles[flavor];
-    if (iter != NULL)
+    if (iter != NULL && thumbnailer->priv->proxy != NULL)
         tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
                                                 GPOINTER_TO_UINT (iter->data), NULL, NULL);
 
@@ -287,9 +303,8 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
          * here only when required */
         if (! rstto_file_is_valid (iter->data))
         {
-            rstto_image_list_remove_file (image_list, iter->data);
-            g_object_unref (iter->data);
-
+            thumbnailer->priv->remove_queue =
+                g_slist_prepend (thumbnailer->priv->remove_queue, iter->data);
             continue;
         }
 
@@ -325,11 +340,12 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
     /* update the list of queued files */
     thumbnailer->priv->in_process_queues[flavor] = g_slist_reverse (temp);
 
-    if (! tumbler_thumbnailer1_call_queue_sync (thumbnailer->priv->proxy,
-                                                (const gchar * const*) uris,
-                                                (const gchar * const*) mimetypes,
-                                                rstto_util_get_thumbnail_flavor_name (flavor),
-                                                "default", 0, &handle, NULL, &error))
+    if (thumbnailer->priv->proxy == NULL
+        || ! tumbler_thumbnailer1_call_queue_sync (thumbnailer->priv->proxy,
+                                                   (const gchar * const*) uris,
+                                                   (const gchar * const*) mimetypes,
+                                                   rstto_util_get_thumbnail_flavor_name (flavor),
+                                                   "default", 0, &handle, NULL, &error))
     {
         if (NULL != error)
         {
@@ -386,6 +402,23 @@ rstto_thumbnailer_queue_request_timer (gpointer user_data)
     return FALSE;
 }
 
+static void
+rstto_thumbnailer_queue_request_timer_destroy (gpointer user_data)
+{
+    RsttoThumbnailer *thumbnailer = user_data;
+    RsttoImageList *image_list;
+
+    image_list = rstto_main_window_get_app_image_list ();
+    for (GSList *iter = thumbnailer->priv->remove_queue; iter != NULL; iter = iter->next)
+    {
+        rstto_image_list_remove_file (image_list, iter->data);
+        g_object_unref (iter->data);
+    }
+
+    g_slist_free (thumbnailer->priv->remove_queue);
+    thumbnailer->priv->remove_queue = NULL;
+}
+
 static RsttoThumbnailFlavor
 rstto_thumbnailer_get_handle_flavor (RsttoThumbnailer *thumbnailer,
                                      guint handle)
